# ListCseIdentitiesResponse

## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**cse_identities** | [**list[CseIdentity]**](CseIdentity.md) | One page of the list of CSE identities configured for the user. | [optional] 
**next_page_token** | **str** | Pagination token to be passed to a subsequent ListCseIdentities call in order to retrieve the next page of identities. If this value is not returned or is the empty string, then no further pages remain. | [optional] 

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)

